==> kdepim-runtime-18.04.1.tar.xz: kdepim-runtime-18.04.1/resources/ews/ewsresource.desktop.cmake <==
[Desktop Entry]
Name=Microsoft Exchange Server (EWS)
Name[ar]=خادوم «مايكروسوفت إكسچينج» (EWS)
Name[ca]=Servidor Microsoft Exchange (EWS)
Name[ca@valencia]=Servidor Microsoft Exchange (EWS)
Name[cs]=Server Microsoft Exchange (EWS)
Name[de]=Microsoft Exchange Server (EWS)
Name[en_GB]=Microsoft Exchange Server (EWS)
Name[es]=Servidor Microsoft Exchange (EWS)
Name[fi]=Microsoft Exchange -palvelin (EWS)
Name[fr]=Microsoft Exchange Server (EWS)
Name[gl]=Servidor de Microsoft Exchange (EWS)
Name[it]=Microsoft Exchange Server (EWS)
Name[ko]=Microsoft Exchange 서버(EWS)
Name[nl]=Microsoft Exchange Server (EWS)
Name[pl]=Microsoft Exchange Server (EWS)
Name[pt]=Servidor de Microsoft Exchange (EWS)
Name[sl]=Strežnik Microsoft Exchange (EWS)
Name[sr]=Мајкрософтов Ексчејнџ-сервер (ЕВС)
Name[sr@ijekavian]=Мајкрософтов Ексчејнџ-сервер (ЕВС)
Name[sr@ijekavianlatin]=Microsoftov Exchange Server (EWS)
Name[sr@latin]=Microsoftov Exchange Server (EWS)
Name[sv]=Microsoft Exchange-server (EWS)
Name[tr]=Microsoft Exchange Sunucusu (EWS)
Name[uk]=Сервер Microsoft Exchange (EWS)
Name[x-test]=xxMicrosoft Exchange Server (EWS)xx
Name[zh_CN]=微软 Exchange 服务器（EWS）
Comment=Provides access to mail, appointments tasks and contacts of a Microsoft Exchange server using EWS
Comment[ar]=يوفّر نفاذًا إلى البريد ومهام المواعيد ومتراسلو خادوم «مايكروسوفت إكسچينج» باستخدام EWS
Comment[ca]=Proporciona accés al correu, tasques de cita i contactes emmagatzemats en un servidor Microsoft Exchange emprant EWS
Comment[ca@valencia]=Proporciona accés al correu, tasques de cita i contactes emmagatzemats en un servidor Microsoft Exchange emprant EWS
Comment[de]=Ermöglicht den Zugriff über EWS auf E-Mails, Termine, Aufgaben und Kontakte, die auf einem Microsoft Exchange Server gespeichert sind.
Comment[en_GB]=Provides access to mail, appointments tasks and contacts of a Microsoft Exchange server using EWS
Comment[es]=Proporciona acceso al correo,citas, tareas y contactos almacenados en un servidor Microsoft Exchange usando EWS.
Comment[fi]=Tarjoaa EWS:llä pääsyn Microsoft Exchange -palvelimen sähköpostiin, tapaamisiin, tehtäviin ja yhteystietoihin
Comment[fr]=Fournit l'accès aux courriels, rendez-vous, tâches et contacts d'un serveur Microsoft Exchange en utilisant EWS
Comment[gl]=Fornece acceso ao correo, citas, tarefas e contractos dun servidor de Microsoft Exchange usando EWS.
Comment[it]=Consente l'accesso a messaggi di posta, appuntamenti, attività e contatti di un server Microsoft Exchange tramite EWS
Comment[ko]=EWS를 사용하여 Microsoft Exchange 서버의 약속, 할 일, 연락처 정보를 가져옵니다
Comment[nl]=Geeft toegang tot e-mail, taken bij afspraken en contactpersonen op een Microsoft Exchange server met EWS.
Comment[pl]=Zapewnia dostęp do poczty, spotkań, zadań i kontaktów serwera Microsoft Exchange przy użyciu EWS
Comment[pt]=Oferece o acesso ao correio, compromissos, tarefas e contactos guardados num servidor Microsoft Exchange, usando o EWS
Comment[sl]=Z uporabo EWS mogoča dostop do pošte, sestankov, opravil in stikov, shranjenih na strežniku Microsoft Exchange
Comment[sr]=Приступ пошти, састанцима, задацима и контактима на Мајкрософтовом Ексчејнџ-серверу користећи ЕВС
Comment[sr@ijekavian]=Приступ пошти, састанцима, задацима и контактима на Мајкрософтовом Ексчејнџ-серверу користећи ЕВС
Comment[sr@ijekavianlatin]=Pristup pošti, sastancima, zadacima i kontaktima na Microsoftovom Exchange Serveru koristeći EWS
Comment[sr@latin]=Pristup pošti, sastancima, zadacima i kontaktima na Microsoftovom Exchange Serveru koristeći EWS
Comment[sv]=Ger tillgång till e-post, möten, uppgifter och kontakter lagrade på en Microsoft Exchange-server med användning av EWS
Comment[tr]=EWS kullanarak bir Microsoft Exchange sunucusunun postalarına, randevularına ve kişilerine erişmenizi sağlar
Comment[uk]=Надає доступ до пошти, записів зустрічей, завдань та контактів, які зберігаються на сервері Microsoft Exchange за допомогою EWS
Comment[x-test]=xxProvides access to mail, appointments tasks and contacts of a Microsoft Exchange server using EWSxx
Comment[zh_CN]=提供使用 EWS 访问微软 Exchange 服务器上的邮件、计划任务和联系人的功能
Type=AkonadiResource
Exec=akonadi_ews_resource
Icon=akonadi-ews

X-Akonadi-MimeTypes=text/directory,message/rfc822,text/calendar,application/x-vnd.kde.contactgroup,application/x-vnd.akonadi.calendar.event,application/x-vnd.akonadi.calendar.todo
X-Akonadi-Capabilities=Resource,NeedsNetwork,@EWS_MTA_CAPABILITIES@
X-Akonadi-Identifier=akonadi_ews_resource

==> kdepim-runtime-18.07.80.tar.xz: kdepim-runtime-18.07.80/resources/ews/ewsresource.desktop.cmake <==
[Desktop Entry]
Name=Microsoft Exchange Server (EWS)
Name[ar]=خادوم «مايكروسوفت إكسچينج» (EWS)
Name[ca]=Servidor Microsoft Exchange (EWS)
Name[ca@valencia]=Servidor Microsoft Exchange (EWS)
Name[cs]=Server Microsoft Exchange (EWS)
Name[de]=Microsoft Exchange Server (EWS)
Name[en_GB]=Microsoft Exchange Server (EWS)
Name[es]=Servidor Microsoft Exchange (EWS)
Name[fi]=Microsoft Exchange -palvelin (EWS)
Name[fr]=Microsoft Exchange Server (EWS)
Name[gl]=Servidor de Microsoft Exchange (EWS)
Name[it]=Microsoft Exchange Server (EWS)
Name[ko]=Microsoft Exchange 서버(EWS)
Name[nl]=Microsoft Exchange Server (EWS)
Name[pl]=Microsoft Exchange Server (EWS)
Name[pt]=Servidor de Microsoft Exchange (EWS)
Name[sl]=Strežnik Microsoft Exchange (EWS)
Name[sr]=Мајкрософтов Ексчејнџ-сервер (ЕВС)
Name[sr@ijekavian]=Мајкрософтов Ексчејнџ-сервер (ЕВС)
Name[sr@ijekavianlatin]=Microsoftov Exchange Server (EWS)
Name[sr@latin]=Microsoftov Exchange Server (EWS)
Name[sv]=Microsoft Exchange-server (EWS)
Name[tr]=Microsoft Exchange Sunucusu (EWS)
Name[uk]=Сервер Microsoft Exchange (EWS)
Name[x-test]=xxMicrosoft Exchange Server (EWS)xx
Name[zh_CN]=微软 Exchange 服务器（EWS）
Name[zh_TW]=Microsoft Exchange 伺服器 (EWS)
Comment=Provides access to mail, appointments tasks and contacts of a Microsoft Exchange server using EWS
Comment[ar]=يوفّر نفاذًا إلى البريد ومهام المواعيد ومتراسلو خادوم «مايكروسوفت إكسچينج» باستخدام EWS
Comment[ca]=Proporciona accés al correu, tasques de cita i contactes emmagatzemats en un servidor Microsoft Exchange emprant EWS
Comment[ca@valencia]=Proporciona accés al correu, tasques de cita i contactes emmagatzemats en un servidor Microsoft Exchange emprant EWS
Comment[de]=Ermöglicht den Zugriff über EWS auf E-Mails, Termine, Aufgaben und Kontakte, die auf einem Microsoft Exchange Server gespeichert sind.
Comment[en_GB]=Provides access to mail, appointments tasks and contacts of a Microsoft Exchange server using EWS
Comment[es]=Proporciona acceso al correo,citas, tareas y contactos almacenados en un servidor Microsoft Exchange usando EWS.
Comment[fi]=Tarjoaa EWS:llä pääsyn Microsoft Exchange -palvelimen sähköpostiin, tapaamisiin, tehtäviin ja yhteystietoihin
Comment[fr]=Fournit l'accès aux courriels, rendez-vous, tâches et contacts d'un serveur Microsoft Exchange en utilisant EWS
Comment[gl]=Fornece acceso ao correo, citas, tarefas e contractos dun servidor de Microsoft Exchange usando EWS.
Comment[it]=Consente l'accesso a messaggi di posta, appuntamenti, attività e contatti di un server Microsoft Exchange tramite EWS
Comment[ko]=EWS를 사용하여 Microsoft Exchange 서버의 약속, 할 일, 연락처 정보를 가져옵니다
Comment[nl]=Geeft toegang tot e-mail, taken bij afspraken en contactpersonen op een Microsoft Exchange server met EWS.
Comment[pl]=Zapewnia dostęp do poczty, spotkań, zadań i kontaktów serwera Microsoft Exchange przy użyciu EWS
Comment[pt]=Oferece o acesso ao correio, compromissos, tarefas e contactos guardados num servidor Microsoft Exchange, usando o EWS
Comment[sl]=Z uporabo EWS mogoča dostop do pošte, sestankov, opravil in stikov, shranjenih na strežniku Microsoft Exchange
Comment[sr]=Приступ пошти, састанцима, задацима и контактима на Мајкрософтовом Ексчејнџ-серверу користећи ЕВС
Comment[sr@ijekavian]=Приступ пошти, састанцима, задацима и контактима на Мајкрософтовом Ексчејнџ-серверу користећи ЕВС
Comment[sr@ijekavianlatin]=Pristup pošti, sastancima, zadacima i kontaktima na Microsoftovom Exchange Serveru koristeći EWS
Comment[sr@latin]=Pristup pošti, sastancima, zadacima i kontaktima na Microsoftovom Exchange Serveru koristeći EWS
Comment[sv]=Ger tillgång till e-post, möten, uppgifter och kontakter lagrade på en Microsoft Exchange-server med användning av EWS
Comment[tr]=EWS kullanarak bir Microsoft Exchange sunucusunun postalarına, randevularına ve kişilerine erişmenizi sağlar
Comment[uk]=Надає доступ до пошти, записів зустрічей, завдань та контактів, які зберігаються на сервері Microsoft Exchange за допомогою EWS
Comment[x-test]=xxProvides access to mail, appointments tasks and contacts of a Microsoft Exchange server using EWSxx
Comment[zh_CN]=提供使用 EWS 访问微软 Exchange 服务器上的邮件、计划任务和联系人的功能
Comment[zh_TW]=提供透過使用 EWS 的 Microsoft Exchange 伺服器存取信箱、約會與聯絡人
Type=AkonadiResource
Exec=akonadi_ews_resource
Icon=akonadi-ews

X-Akonadi-MimeTypes=text/directory,message/rfc822,text/calendar,application/x-vnd.kde.contactgroup,application/x-vnd.akonadi.calendar.event,application/x-vnd.akonadi.calendar.todo
X-Akonadi-Capabilities=Resource,NeedsNetwork,@EWS_MTA_CAPABILITIES@
X-Akonadi-Identifier=akonadi_ews_resource
